@@ -2,28 +2,29 @@ package performanceprofile
 
 import (
 	"context"
-	"encoding/base64"
+	"encoding/json"
 	"fmt"
+	"regexp"
 	"time"
 
-	"github.com/openshift-kni/performance-addon-operators/pkg/controller/performanceprofile/components/featuregate"
-	"github.com/openshift-kni/performance-addon-operators/pkg/controller/performanceprofile/components/kubeletconfig"
-	"github.com/openshift-kni/performance-addon-operators/pkg/controller/performanceprofile/components/machineconfig"
-	"github.com/openshift-kni/performance-addon-operators/pkg/controller/performanceprofile/components/tuned"
-
 	. "github.com/onsi/ginkgo"
 	. "github.com/onsi/gomega"
 	. "github.com/onsi/gomega/gstruct"
 
-	performancev1alpha1 "github.com/openshift-kni/performance-addon-operators/pkg/apis/performance/v1alpha1"
+	igntypes "github.com/coreos/ignition/config/v2_2/types"
+	performancev1 "github.com/openshift-kni/performance-addon-operators/pkg/apis/performance/v1"
 	"github.com/openshift-kni/performance-addon-operators/pkg/controller/performanceprofile/components"
+	"github.com/openshift-kni/performance-addon-operators/pkg/controller/performanceprofile/components/kubeletconfig"
+	"github.com/openshift-kni/performance-addon-operators/pkg/controller/performanceprofile/components/machineconfig"
+	"github.com/openshift-kni/performance-addon-operators/pkg/controller/performanceprofile/components/runtimeclass"
+	"github.com/openshift-kni/performance-addon-operators/pkg/controller/performanceprofile/components/tuned"
 	testutils "github.com/openshift-kni/performance-addon-operators/pkg/utils/testing"
-	configv1 "github.com/openshift/api/config/v1"
 	tunedv1 "github.com/openshift/cluster-node-tuning-operator/pkg/apis/tuned/v1"
 	conditionsv1 "github.com/openshift/custom-resource-status/conditions/v1"
 	mcov1 "github.com/openshift/machine-config-operator/pkg/apis/machineconfiguration.openshift.io/v1"
 
 	corev1 "k8s.io/api/core/v1"
+	nodev1beta1 "k8s.io/api/node/v1beta1"
 	"k8s.io/apimachinery/pkg/api/errors"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/runtime"
@@ -40,7 +41,7 @@ const assetsDir = "../../../build/assets"
 
 var _ = Describe("Controller", func() {
 	var request reconcile.Request
-	var profile *performancev1alpha1.PerformanceProfile
+	var profile *performancev1.PerformanceProfile
 
 	BeforeEach(func() {
 		profile = testutils.NewPerformanceProfile("test")
@@ -57,7 +58,7 @@ var _ = Describe("Controller", func() {
 
 		Expect(reconcileTimes(r, request, 1)).To(Equal(reconcile.Result{}))
 
-		updatedProfile := &performancev1alpha1.PerformanceProfile{}
+		updatedProfile := &performancev1.PerformanceProfile{}
 		key := types.NamespacedName{
 			Name:      profile.Name,
 			Namespace: metav1.NamespaceNone,
@@ -79,7 +80,7 @@ var _ = Describe("Controller", func() {
 			// once we will have validation webhook, this test will not be relevant anymore
 			Expect(reconcileTimes(r, request, 1)).To(Equal(reconcile.Result{}))
 
-			updatedProfile := &performancev1alpha1.PerformanceProfile{}
+			updatedProfile := &performancev1.PerformanceProfile{}
 			key := types.NamespacedName{
 				Name:      profile.Name,
 				Namespace: metav1.NamespaceNone,
@@ -106,10 +107,10 @@ var _ = Describe("Controller", func() {
 			Expect(errors.IsNotFound(err)).To(Equal(true))
 		})
 
-		It("should create all resources except KubeletConfig on first reconcile loop", func() {
+		It("should create all resources on first reconcile loop", func() {
 			r := newFakeReconciler(profile)
 
-			Expect(reconcileTimes(r, request, 1)).To(Equal(reconcile.Result{RequeueAfter: 10 * time.Second}))
+			Expect(reconcileTimes(r, request, 1)).To(Equal(reconcile.Result{}))
 
 			name := components.GetComponentName(profile.Name, components.ComponentNamePrefix)
 			key := types.NamespacedName{
@@ -122,15 +123,14 @@ var _ = Describe("Controller", func() {
 			err := r.client.Get(context.TODO(), key, mc)
 			Expect(err).ToNot(HaveOccurred())
 
-			// verify that KubeletConfig wasn't created
+			// verify KubeletConfig creation
 			kc := &mcov1.KubeletConfig{}
 			err = r.client.Get(context.TODO(), key, kc)
-			Expect(errors.IsNotFound(err)).To(BeTrue())
+			Expect(err).ToNot(HaveOccurred())
 
-			// verify FeatureGate creation
-			fg := &configv1.FeatureGate{}
-			key.Name = components.FeatureGateLatencySensetiveName
-			err = r.client.Get(context.TODO(), key, fg)
+			// verify RuntimeClass creation
+			runtimeClass := &nodev1beta1.RuntimeClass{}
+			err = r.client.Get(context.TODO(), key, runtimeClass)
 			Expect(err).ToNot(HaveOccurred())
 
 			// verify tuned performance creation
@@ -141,28 +141,11 @@ var _ = Describe("Controller", func() {
 			Expect(err).ToNot(HaveOccurred())
 		})
 
-		It("should create KubeletConfig on second reconcile loop", func() {
+		It("should create event on the second reconcile loop", func() {
 			r := newFakeReconciler(profile)
 
 			Expect(reconcileTimes(r, request, 2)).To(Equal(reconcile.Result{}))
 
-			name := components.GetComponentName(profile.Name, components.ComponentNamePrefix)
-			key := types.NamespacedName{
-				Name:      name,
-				Namespace: metav1.NamespaceNone,
-			}
-
-			// verify KubeletConfig creation
-			kc := &mcov1.KubeletConfig{}
-			err := r.client.Get(context.TODO(), key, kc)
-			Expect(err).ToNot(HaveOccurred())
-		})
-
-		It("should create event on third reconcile loop", func() {
-			r := newFakeReconciler(profile)
-
-			Expect(reconcileTimes(r, request, 3)).To(Equal(reconcile.Result{}))
-
 			// verify creation event
 			fakeRecorder, ok := r.recorder.(*record.FakeRecorder)
 			Expect(ok).To(BeTrue())
@@ -173,9 +156,9 @@ var _ = Describe("Controller", func() {
 		It("should update the profile status", func() {
 			r := newFakeReconciler(profile)
 
-			Expect(reconcileTimes(r, request, 1)).To(Equal(reconcile.Result{RequeueAfter: 10 * time.Second}))
+			Expect(reconcileTimes(r, request, 1)).To(Equal(reconcile.Result{}))
 
-			updatedProfile := &performancev1alpha1.PerformanceProfile{}
+			updatedProfile := &performancev1.PerformanceProfile{}
 			key := types.NamespacedName{
 				Name:      profile.Name,
 				Namespace: metav1.NamespaceNone,
@@ -227,8 +210,9 @@ var _ = Describe("Controller", func() {
 			err = r.client.Get(context.TODO(), keyB, tb)
 			Expect(err).ToNot(HaveOccurred())
 
-			_, err = r.Reconcile(request)
+			result, err := r.Reconcile(request)
 			Expect(err).ToNot(HaveOccurred())
+			Expect(result).To(Equal(reconcile.Result{}))
 
 			tunedList := &tunedv1.TunedList{}
 			err = r.client.List(context.TODO(), tunedList)
@@ -239,7 +223,7 @@ var _ = Describe("Controller", func() {
 		})
 
 		It("should create nothing when pause annotation is set", func() {
-			profile.Annotations = map[string]string{performancev1alpha1.PerformanceProfilePauseAnnotation: "true"}
+			profile.Annotations = map[string]string{performancev1.PerformanceProfilePauseAnnotation: "true"}
 			r := newFakeReconciler(profile)
 
 			Expect(reconcileTimes(r, request, 1)).To(Equal(reconcile.Result{}))
@@ -265,25 +249,24 @@ var _ = Describe("Controller", func() {
 			err = r.client.Get(context.TODO(), key, mcp)
 			Expect(errors.IsNotFound(err)).To(BeTrue())
 
-			// verify FeatureGate wasn't created
-			fg := &configv1.FeatureGate{}
-			key.Name = components.FeatureGateLatencySensetiveName
-			err = r.client.Get(context.TODO(), key, fg)
-			Expect(errors.IsNotFound(err)).To(BeTrue())
-
 			// verify tuned Performance wasn't created
 			tunedPerformance := &tunedv1.Tuned{}
 			key.Name = components.ProfileNamePerformance
 			key.Namespace = components.NamespaceNodeTuningOperator
 			err = r.client.Get(context.TODO(), key, tunedPerformance)
 			Expect(errors.IsNotFound(err)).To(BeTrue())
+
+			// verify that no RuntimeClass was created
+			runtimeClass := &nodev1beta1.RuntimeClass{}
+			err = r.client.Get(context.TODO(), key, runtimeClass)
+			Expect(errors.IsNotFound(err)).To(BeTrue())
 		})
 
 		Context("when all components exist", func() {
 			var mc *mcov1.MachineConfig
 			var kc *mcov1.KubeletConfig
-			var fg *configv1.FeatureGate
 			var tunedPerformance *tunedv1.Tuned
+			var runtimeClass *nodev1beta1.RuntimeClass
 
 			BeforeEach(func() {
 				var err error
@@ -293,15 +276,14 @@ var _ = Describe("Controller", func() {
 				kc, err = kubeletconfig.New(profile)
 				Expect(err).ToNot(HaveOccurred())
 
-				fg = featuregate.NewLatencySensitive()
-
 				tunedPerformance, err = tuned.NewNodePerformance(assetsDir, profile)
 				Expect(err).ToNot(HaveOccurred())
 
+				runtimeClass = runtimeclass.New(profile, machineconfig.HighPerformanceRuntime)
 			})
 
 			It("should not record new create event", func() {
-				r := newFakeReconciler(profile, mc, kc, fg, tunedPerformance)
+				r := newFakeReconciler(profile, mc, kc, tunedPerformance, runtimeClass)
 
 				Expect(reconcileTimes(r, request, 1)).To(Equal(reconcile.Result{}))
 
@@ -318,7 +300,7 @@ var _ = Describe("Controller", func() {
 
 			It("should update MC when RT kernel gets disabled", func() {
 				profile.Spec.RealTimeKernel.Enabled = pointer.BoolPtr(false)
-				r := newFakeReconciler(profile, mc, kc, fg, tunedPerformance)
+				r := newFakeReconciler(profile, mc, kc, tunedPerformance)
 
 				Expect(reconcileTimes(r, request, 1)).To(Equal(reconcile.Result{}))
 
@@ -337,14 +319,14 @@ var _ = Describe("Controller", func() {
 			})
 
 			It("should update MC, KC and Tuned when CPU params change", func() {
-				reserved := performancev1alpha1.CPUSet("0-1")
-				isolated := performancev1alpha1.CPUSet("2-3")
-				profile.Spec.CPU = &performancev1alpha1.CPU{
+				reserved := performancev1.CPUSet("0-1")
+				isolated := performancev1.CPUSet("2-3")
+				profile.Spec.CPU = &performancev1.CPU{
 					Reserved: &reserved,
 					Isolated: &isolated,
 				}
 
-				r := newFakeReconciler(profile, mc, kc, fg, tunedPerformance)
+				r := newFakeReconciler(profile, mc, kc, tunedPerformance)
 
 				Expect(reconcileTimes(r, request, 1)).To(Equal(reconcile.Result{}))
 
@@ -353,29 +335,9 @@ var _ = Describe("Controller", func() {
 					Namespace: metav1.NamespaceNone,
 				}
 
-				By("Verifying MC update for isolated")
-				mc := &mcov1.MachineConfig{}
-				err := r.client.Get(context.TODO(), key, mc)
-				Expect(err).ToNot(HaveOccurred())
-				Expect(mc.Spec.KernelArguments).ToNot(ContainElement(ContainSubstring(`"isolcpus`)))
-
-				By("Verifying MC update for reserved")
-
-				contentBase64 := base64.StdEncoding.EncodeToString([]byte("[Manager]\nCPUAffinity=" + string(*profile.Spec.CPU.Reserved)))
-				Expect(mc.Spec.Config.Storage.Files).To(ContainElement(MatchFields(IgnoreMissing|IgnoreExtras, Fields{
-					"FileEmbedded1": MatchFields(IgnoreMissing|IgnoreExtras, Fields{
-						"Contents": MatchFields(IgnoreMissing|IgnoreExtras, Fields{
-							"Source": ContainSubstring(contentBase64),
-						}),
-					}),
-				})))
-
-				reservedCPUMask, err := components.CPUListToMaskList(string(*profile.Spec.CPU.Reserved))
-				Expect(mc.Spec.KernelArguments).To(ContainElement(ContainSubstring("tuned.non_isolcpus=" + reservedCPUMask)))
-
 				By("Verifying KC update for reserved")
 				kc := &mcov1.KubeletConfig{}
-				err = r.client.Get(context.TODO(), key, kc)
+				err := r.client.Get(context.TODO(), key, kc)
 				Expect(err).ToNot(HaveOccurred())
 				Expect(string(kc.Spec.KubeletConfig.Raw)).To(ContainSubstring(fmt.Sprintf(`"reservedSystemCPUs":"%s"`, string(*profile.Spec.CPU.Reserved))))
 
@@ -388,41 +350,61 @@ var _ = Describe("Controller", func() {
 				err = r.client.Get(context.TODO(), key, t)
 				Expect(err).ToNot(HaveOccurred())
 				Expect(*t.Spec.Profile[0].Data).To(ContainSubstring("isolated_cores=" + string(*profile.Spec.CPU.Isolated)))
-
-				By("Verifying Tuned update for isolated")
-				Expect(*t.Spec.Profile[0].Data).To(ContainSubstring("/sys/bus/workqueue/devices/writeback/cpumask = " + reservedCPUMask))
 			})
 
-			It("should add isolcpus to MC kargs when balanced set to false", func() {
-				reserved := performancev1alpha1.CPUSet("0-1")
-				isolated := performancev1alpha1.CPUSet("2-3")
-				profile.Spec.CPU = &performancev1alpha1.CPU{
+			It("should add isolcpus with managed_irq flag to tuned profile when balanced set to true", func() {
+				reserved := performancev1.CPUSet("0-1")
+				isolated := performancev1.CPUSet("2-3")
+				profile.Spec.CPU = &performancev1.CPU{
+					Reserved:        &reserved,
+					Isolated:        &isolated,
+					BalanceIsolated: pointer.BoolPtr(true),
+				}
+
+				r := newFakeReconciler(profile, mc, kc, tunedPerformance)
+
+				Expect(reconcileTimes(r, request, 1)).To(Equal(reconcile.Result{}))
+
+				key := types.NamespacedName{
+					Name:      components.GetComponentName(profile.Name, components.ProfileNamePerformance),
+					Namespace: components.NamespaceNodeTuningOperator,
+				}
+				t := &tunedv1.Tuned{}
+				err := r.client.Get(context.TODO(), key, t)
+				Expect(err).ToNot(HaveOccurred())
+				cmdlineRealtimeWithoutCPUBalancing := regexp.MustCompile(`\s*cmdline_realtime=\+\s*tsc=nowatchdog\s+intel_iommu=on\s+iommu=pt\s+isolcpus=managed_irq\s*`)
+				Expect(cmdlineRealtimeWithoutCPUBalancing.MatchString(*t.Spec.Profile[0].Data)).To(BeTrue())
+			})
+
+			It("should add isolcpus with domain,managed_irq flags to tuned profile when balanced set to false", func() {
+				reserved := performancev1.CPUSet("0-1")
+				isolated := performancev1.CPUSet("2-3")
+				profile.Spec.CPU = &performancev1.CPU{
 					Reserved:        &reserved,
 					Isolated:        &isolated,
 					BalanceIsolated: pointer.BoolPtr(false),
 				}
 
-				r := newFakeReconciler(profile, mc, kc, fg, tunedPerformance)
+				r := newFakeReconciler(profile, mc, kc, tunedPerformance)
 
 				Expect(reconcileTimes(r, request, 1)).To(Equal(reconcile.Result{}))
 
 				key := types.NamespacedName{
-					Name:      components.GetComponentName(profile.Name, components.ComponentNamePrefix),
-					Namespace: metav1.NamespaceNone,
+					Name:      components.GetComponentName(profile.Name, components.ProfileNamePerformance),
+					Namespace: components.NamespaceNodeTuningOperator,
 				}
-
-				By("Verifying MC update for isolated")
-				mc := &mcov1.MachineConfig{}
-				err := r.client.Get(context.TODO(), key, mc)
+				t := &tunedv1.Tuned{}
+				err := r.client.Get(context.TODO(), key, t)
 				Expect(err).ToNot(HaveOccurred())
-				Expect(mc.Spec.KernelArguments).To(ContainElement(ContainSubstring("isolcpus=" + string(*profile.Spec.CPU.Isolated))))
+				cmdlineRealtimeWithoutCPUBalancing := regexp.MustCompile(`\s*cmdline_realtime=\+\s*tsc=nowatchdog\s+intel_iommu=on\s+iommu=pt\s+isolcpus=domain,managed_irq,\s*`)
+				Expect(cmdlineRealtimeWithoutCPUBalancing.MatchString(*t.Spec.Profile[0].Data)).To(BeTrue())
 			})
 
 			It("should update MC when Hugepages params change without node added", func() {
-				size := performancev1alpha1.HugePageSize("2M")
-				profile.Spec.HugePages = &performancev1alpha1.HugePages{
+				size := performancev1.HugePageSize("2M")
+				profile.Spec.HugePages = &performancev1.HugePages{
 					DefaultHugePagesSize: &size,
-					Pages: []performancev1alpha1.HugePage{
+					Pages: []performancev1.HugePage{
 						{
 							Count: 8,
 							Size:  size,
@@ -430,30 +412,27 @@ var _ = Describe("Controller", func() {
 					},
 				}
 
-				r := newFakeReconciler(profile, mc, kc, fg, tunedPerformance)
+				r := newFakeReconciler(profile, mc, kc, tunedPerformance)
 
 				Expect(reconcileTimes(r, request, 1)).To(Equal(reconcile.Result{}))
 
+				By("Verifying Tuned profile update")
 				key := types.NamespacedName{
-					Name:      components.GetComponentName(profile.Name, components.ComponentNamePrefix),
-					Namespace: metav1.NamespaceNone,
+					Name:      components.GetComponentName(profile.Name, components.ProfileNamePerformance),
+					Namespace: components.NamespaceNodeTuningOperator,
 				}
-
-				By("Verifying MC update")
-				mc := &mcov1.MachineConfig{}
-				err := r.client.Get(context.TODO(), key, mc)
+				t := &tunedv1.Tuned{}
+				err := r.client.Get(context.TODO(), key, t)
 				Expect(err).ToNot(HaveOccurred())
-				Expect(mc.Spec.KernelArguments).To(ContainElement(ContainSubstring("default_hugepagesz=2M")))
-				Expect(mc.Spec.KernelArguments).To(ContainElement(ContainSubstring("hugepagesz=2M")))
-				Expect(mc.Spec.KernelArguments).To(ContainElement(ContainSubstring("hugepages=8")))
-
+				cmdlineHugepages := regexp.MustCompile(`\s*cmdline_hugepages=\+\s*default_hugepagesz=2M\s+hugepagesz=2M\s+hugepages=8\s*`)
+				Expect(cmdlineHugepages.MatchString(*t.Spec.Profile[0].Data)).To(BeTrue())
 			})
 
-			It("should update MC when Hugepages params change with node added", func() {
-				size := performancev1alpha1.HugePageSize("2M")
-				profile.Spec.HugePages = &performancev1alpha1.HugePages{
+			It("should update Tuned when Hugepages params change with node added", func() {
+				size := performancev1.HugePageSize("2M")
+				profile.Spec.HugePages = &performancev1.HugePages{
 					DefaultHugePagesSize: &size,
-					Pages: []performancev1alpha1.HugePage{
+					Pages: []performancev1.HugePage{
 						{
 							Count: 8,
 							Size:  size,
@@ -462,24 +441,35 @@ var _ = Describe("Controller", func() {
 					},
 				}
 
-				r := newFakeReconciler(profile, mc, kc, fg, tunedPerformance)
+				r := newFakeReconciler(profile, mc, kc, tunedPerformance)
 
 				Expect(reconcileTimes(r, request, 1)).To(Equal(reconcile.Result{}))
 
+				By("Verifying Tuned update")
 				key := types.NamespacedName{
+					Name:      components.GetComponentName(profile.Name, components.ProfileNamePerformance),
+					Namespace: components.NamespaceNodeTuningOperator,
+				}
+				t := &tunedv1.Tuned{}
+				err := r.client.Get(context.TODO(), key, t)
+				Expect(err).ToNot(HaveOccurred())
+				cmdlineHugepages := regexp.MustCompile(`\s*cmdline_hugepages=\+\s*`)
+				Expect(cmdlineHugepages.MatchString(*t.Spec.Profile[0].Data)).To(BeTrue())
+
+				By("Verifying MC update")
+				key = types.NamespacedName{
 					Name:      components.GetComponentName(profile.Name, components.ComponentNamePrefix),
 					Namespace: metav1.NamespaceNone,
 				}
-
-				By("Verifying MC update")
 				mc := &mcov1.MachineConfig{}
-				err := r.client.Get(context.TODO(), key, mc)
+				err = r.client.Get(context.TODO(), key, mc)
 				Expect(err).ToNot(HaveOccurred())
-				Expect(mc.Spec.KernelArguments).To(ContainElement(ContainSubstring("default_hugepagesz=2M")))
-				Expect(mc.Spec.KernelArguments).ToNot(ContainElement(ContainSubstring(`"hugepagesz`)))
-				Expect(mc.Spec.KernelArguments).ToNot(ContainElement(ContainSubstring(`"hugepages`)))
 
-				Expect(mc.Spec.Config.Systemd.Units).To(ContainElement(MatchFields(IgnoreMissing|IgnoreExtras, Fields{
+				config := &igntypes.Config{}
+				err = json.Unmarshal(mc.Spec.Config.Raw, config)
+				Expect(err).ToNot(HaveOccurred())
+
+				Expect(config.Systemd.Units).To(ContainElement(MatchFields(IgnoreMissing|IgnoreExtras, Fields{
 					"Contents": And(
 						ContainSubstring("Description=Hugepages"),
 						ContainSubstring("Environment=HUGEPAGES_COUNT=8"),
@@ -490,6 +480,49 @@ var _ = Describe("Controller", func() {
 
 			})
 
+			It("should update status with generated tuned", func() {
+				r := newFakeReconciler(profile, mc, kc, tunedPerformance)
+				Expect(reconcileTimes(r, request, 1)).To(Equal(reconcile.Result{}))
+				key := types.NamespacedName{
+					Name:      components.GetComponentName(profile.Name, components.ProfileNamePerformance),
+					Namespace: components.NamespaceNodeTuningOperator,
+				}
+				t := &tunedv1.Tuned{}
+				err := r.client.Get(context.TODO(), key, t)
+				Expect(err).ToNot(HaveOccurred())
+				tunedNamespacedName := namespacedName(t).String()
+				updatedProfile := &performancev1.PerformanceProfile{}
+				key = types.NamespacedName{
+					Name:      profile.Name,
+					Namespace: metav1.NamespaceNone,
+				}
+				Expect(r.client.Get(context.TODO(), key, updatedProfile)).ToNot(HaveOccurred())
+				Expect(updatedProfile.Status.Tuned).NotTo(BeNil())
+				Expect(*updatedProfile.Status.Tuned).To(Equal(tunedNamespacedName))
+			})
+
+			It("should update status with generated runtime class", func() {
+				r := newFakeReconciler(profile, mc, kc, tunedPerformance, runtimeClass)
+				Expect(reconcileTimes(r, request, 1)).To(Equal(reconcile.Result{}))
+
+				key := types.NamespacedName{
+					Name:      components.GetComponentName(profile.Name, components.ComponentNamePrefix),
+					Namespace: metav1.NamespaceAll,
+				}
+				runtimeClass := &nodev1beta1.RuntimeClass{}
+				err := r.client.Get(context.TODO(), key, runtimeClass)
+				Expect(err).ToNot(HaveOccurred())
+
+				updatedProfile := &performancev1.PerformanceProfile{}
+				key = types.NamespacedName{
+					Name:      profile.Name,
+					Namespace: metav1.NamespaceAll,
+				}
+				Expect(r.client.Get(context.TODO(), key, updatedProfile)).ToNot(HaveOccurred())
+				Expect(updatedProfile.Status.RuntimeClass).NotTo(BeNil())
+				Expect(*updatedProfile.Status.RuntimeClass).To(Equal(runtimeClass.Name))
+			})
+
 			It("should update status when MCP is degraded", func() {
 				mcpReason := "mcpReason"
 				mcpMessage := "MCP message"
@@ -525,11 +558,11 @@ var _ = Describe("Controller", func() {
 					},
 				}
 
-				r := newFakeReconciler(profile, mc, kc, fg, tunedPerformance, mcp)
+				r := newFakeReconciler(profile, mc, kc, tunedPerformance, mcp)
 
 				Expect(reconcileTimes(r, request, 1)).To(Equal(reconcile.Result{}))
 
-				updatedProfile := &performancev1alpha1.PerformanceProfile{}
+				updatedProfile := &performancev1.PerformanceProfile{}
 				key := types.NamespacedName{
 					Name:      profile.Name,
 					Namespace: metav1.NamespaceNone,
@@ -566,12 +599,12 @@ var _ = Describe("Controller", func() {
 			kc, err := kubeletconfig.New(profile)
 			Expect(err).ToNot(HaveOccurred())
 
-			fg := featuregate.NewLatencySensitive()
-
 			tunedPerformance, err := tuned.NewNodePerformance(assetsDir, profile)
 			Expect(err).ToNot(HaveOccurred())
 
-			r := newFakeReconciler(profile, mc, kc, fg, tunedPerformance)
+			runtimeClass := runtimeclass.New(profile, machineconfig.HighPerformanceRuntime)
+
+			r := newFakeReconciler(profile, mc, kc, tunedPerformance, runtimeClass)
 			result, err := r.Reconcile(request)
 			Expect(err).ToNot(HaveOccurred())
 			Expect(result).To(Equal(reconcile.Result{}))
@@ -591,11 +624,9 @@ var _ = Describe("Controller", func() {
 			err = r.client.Get(context.TODO(), key, kc)
 			Expect(errors.IsNotFound(err)).To(Equal(true))
 
-			// verify feature gate deletion
-			// TOOD: uncomment once https://bugzilla.redhat.com/show_bug.cgi?id=1788061 fixed
-			// key.Name = components.FeatureGateLatencySensetiveName
-			// err = r.client.Get(context.TODO(), key, fg)
-			// Expect(errors.IsNotFound(err)).To(Equal(true))
+			// verify RuntimeClass deletion
+			err = r.client.Get(context.TODO(), key, runtimeClass)
+			Expect(errors.IsNotFound(err)).To(Equal(true))
 
 			// verify tuned real-time kernel deletion
 			key.Name = components.GetComponentName(profile.Name, components.ProfileNamePerformance)
@@ -606,7 +637,7 @@ var _ = Describe("Controller", func() {
 			// verify finalizer deletion
 			key.Name = profile.Name
 			key.Namespace = metav1.NamespaceNone
-			updatedProfile := &performancev1alpha1.PerformanceProfile{}
+			updatedProfile := &performancev1.PerformanceProfile{}
 			Expect(r.client.Get(context.TODO(), key, updatedProfile)).ToNot(HaveOccurred())
 			Expect(hasFinalizer(updatedProfile, finalizer)).To(Equal(false))
 		})
@@ -625,7 +656,7 @@ func reconcileTimes(reconciler *ReconcilePerformanceProfile, request reconcile.R
 
 // newFakeReconciler returns a new reconcile.Reconciler with a fake client
 func newFakeReconciler(initObjects ...runtime.Object) *ReconcilePerformanceProfile {
-	fakeClient := fake.NewFakeClient(initObjects...)
+	fakeClient := fake.NewFakeClientWithScheme(scheme.Scheme, initObjects...)
 	fakeRecorder := record.NewFakeRecorder(10)
 	return &ReconcilePerformanceProfile{
 		client:    fakeClient,
